@@ -72,7 +72,7 @@ LockStruct  LockProcs[] =
 	 "Shows Langton's and Turk's generalized ants", 0, NULL, NULL},
 #ifdef USE_GL
 	{"atlantis",
-	 1000, 4, 100, 6000, 64, 1.0, "",
+	 18000, 4, 100, 6000, 64, 1.0, "",
 	 "Shows moving sharks/whales/dolphin", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"ball",
@@ -106,7 +106,7 @@ LockStruct  LockProcs[] =
 	 "Shows Palmiter's bug evolution and garden of Eden", 0, NULL, NULL},
 #ifdef USE_GL
 	{"cage",
-	 1000, 1, 1, 1, 64, 1.0, "",
+	 25000, 1, 1, 1, 64, 1.0, "",
 	 "Shows the Impossible Cage, an Escher-like GL scene", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"clock",
@@ -136,15 +136,18 @@ LockStruct  LockProcs[] =
 	{"dilemma",
 	 200000, -2, 1000, 0, 64, 1.0, "",
 	 "Shows Lloyd's Prisoner's Dilemma simulation", 0, NULL, NULL},
+	{"dragon",
+	 2000000, 1, 16, -24, 64, 1.0, "",
+	 "Shows Deventer's Hexagonal Dragons Maze", 0, NULL, NULL},
 	{"discrete",
 	 1000, 4096, 2500, 1, 64, 1.0, "",
 	 "Shows various discrete maps", 0, NULL, NULL},
 	{"drift",
 	 10000, 30, 1, 1, 64, 1.0, "",
 	 "Shows cosmic drifting flame fractals", 0, NULL, NULL},
-    {"euler2d",
-     1000, 1024, 3000, 1, 64, 1.0, "",
-     "Shows a simulation of 2D incompressible inviscid fluid", 0, NULL, NULL},
+	{"euler2d",
+	 1000, 1024, 3000, 1, 64, 1.0, "",
+	 "Shows a simulation of 2D incompressible inviscid fluid", 0, NULL, NULL},
 	{"eyes",
 	 20000, -8, 5, 1, 64, 1.0, "",
 	 "Shows eyes following a bouncing grelb", 0, NULL, NULL},
@@ -175,6 +178,11 @@ LockStruct  LockProcs[] =
 	{"gears",
 	 1000, 1, 2, 1, 64, 1.0, "",
 	 "Shows GL's gears", 0, NULL, "#ifdef USE_GL"},
+#endif
+#ifdef USE_GL
+	{"glplanet",
+	 1000, 1, 2, 1, 64, 1.0, "",
+	 "Animates texture mapped sphere (planet)", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"goop",
 	 10000, -12, 1, 1, 64, 1.0, "",
@@ -244,7 +252,7 @@ LockStruct  LockProcs[] =
 	 10000, 1, 2000, -200, 64, 0.6, "",
 	 "Shows lissajous worms", 0, NULL, NULL},
 	{"loop",
-	 100000, 1, 1600, -12, 64, 1.0, "",
+	 100000, -5, 1600, -12, 64, 1.0, "",
 	 "Shows Langton's self-producing loops", 0, NULL, NULL},
 	{"lyapunov",
 	 25000, 600, 1, 1, 64, 1.0, "",
@@ -265,6 +273,9 @@ LockStruct  LockProcs[] =
 	{"moebius",
 	 1000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL, "#ifdef USE_GL"},
+	{(char *) "molecule",
+	 50000, 1, 20, 1, 64, 1.0, "",
+	 "Draws molecules", 0, NULL, "#ifdef USE_GL"},
 	{"morph3d",
 	 1000, 0, 1, 1, 64, 1.0, "",
 	 "Shows GL morphing polyhedra", 0, NULL, "#ifdef USE_GL"},
@@ -284,9 +295,6 @@ LockStruct  LockProcs[] =
 	{"penrose",
 	 10000, 1, 1, -40, 64, 1.0, "",
 	 "Shows Penrose's quasiperiodic tilings", 0, NULL, NULL},
-	{"pentominoes",
-	 1000, 1, 1, 1, 64, 1.0, "",
-	 "Shows attempts to place pentominoes into a rectangle", 0, NULL, NULL},
 	{"petal",
 	 10000, -500, 400, 1, 64, 1.0, "",
 	 "Shows various GCD Flowers", 0, NULL, NULL},
@@ -295,6 +303,9 @@ LockStruct  LockProcs[] =
 	 1000, 2, 5, 500, 64, 1.0, "",
 	 "Shows a selfbuilding pipe system", 0, NULL, "#ifdef USE_GL"},
 #endif
+	{"polyominoes",
+	 6000, 1, 8192, 1, 64, 1.0, "",
+	 "Shows attempts to place polyominoes into a rectangle", 0, NULL, NULL},
 	{"puzzle",
 	 10000, 250, 1, 1, 64, 1.0, "",
 	 "Shows a puzzle being scrambled and then solved", 0, NULL, NULL},
@@ -320,12 +331,20 @@ LockStruct  LockProcs[] =
 	 10000, 0, 10, 400, 64, 1.0, "",
 	 "Balls spinning like crazy in GL", 0, NULL, "#ifdef USE_GL"},
 #endif
+        {"scooter",
+         20000, 24, 3, 100, 64, 1.0, "",
+         "Shows a journey through space tunnel and stars", 0, NULL, NULL},
 	{"shape",
 	 10000, 100, 256, 1, 64, 1.0, "",
 	 "Shows stippled rectangles, ellipses, and triangles", 0, NULL, NULL},
 	{"sierpinski",
 	 400000, 2000, 100, 1, 64, 1.0, "",
 	 "Shows Sierpinski's triangle", 0, NULL, NULL},
+#ifdef USE_GL
+	{"sierpinski3d",
+         1000, 1, 2, 1, 64, 1.0, "",
+         "Shows GL's Sierpinski gasket", 0, NULL, "#ifdef USE_GL"},
+#endif
 #if defined(USE_GL) && defined( USE_UNSTABLE )
 	{"skewb",
 	 10000, -30, 5, 1, 64, 1.0, "",
@@ -339,11 +358,9 @@ LockStruct  LockProcs[] =
 	 2000000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Klondike's game of solitare", 0, NULL, "#ifdef HAVE_CXX"},
 #endif
-#ifdef USE_UNSTABLE
 	{"space",
 	 10000, 100, 1, 15, 64, 1.0, "",
 	 "Shows a journey into deep space", 0, NULL, "#ifdef USE_UNSTABLE"},
-#endif
 	{"sphere",
 	 5000, 1, 20, 0, 64, 1.0, "",
 	 "Shows a bunch of shaded spheres", 0, NULL, NULL},
