@@ -16,6 +16,8 @@ XCOMM  #define CPPCompiler
 XCOMM  #define XpmLibrary
 XCOMM  #define XmLibrary
 XCOMM  #define GLLibrary
+XCOMM  #define TtfLibrary
+XCOMM  #define GlttLibrary
 XCOMM  #define DtSaverLibrary
 XCOMM  #define DPMSLibrary
 XCOMM  #define RplayLibrary
@@ -42,12 +44,14 @@ XCOMM  CC = acc
 XCOMM  CC = CC
 XCOMM  CC = gcc -Wall
 XCOMM  CC = g++ -Wall
+XCOMM  CXX = g++ -Wall
+XCOMM  CXX = CC
 
 LN_S = $(LN)
 
 XCOMM   *** BEGIN C++ CONFIG SECTION ***
 
-XCOMM Only the invert.c and text3d.cc modes use this.
+XCOMM Only the solitare, invert.c, and text3d.cc modes use this.
 XCOMM modes use this.
 XCOMM If your system has libXpm, remove the 'XCOMM  ' from the next line.
 XCOMM  #define CPPCompiler
@@ -56,7 +60,17 @@ XCOMM If your system has C++, remove the 'XCOMM  ' from the next line.
 #ifdef CPPCompiler
 CPPDEF = -DHAVE_CXX
 XCOMM Need this to get text3d.cc to work.
-XCOMM CPPDEF += -DHAVE_TTF -DHAVE_GLTT
+XCOMM If your system has these 2 remove the 'XCOMM  ' from the next 2 lines.
+XCOMM  #define TtfLibrary
+XCOMM  #define GlttLibrary
+
+#ifdef TtfLibrary
+#ifdef GlttLibrary
+CPPDEF += -DHAVE_TTF -DHAVE_GLTT
+GLTTLIB = -L/usr/local/lib -lgltt
+TTFLIB = -L/usr/local/lib -lttf
+#endif
+#endif
 #endif
 
 XCOMM   *** END C++ CONFIG SECTION ***
@@ -116,7 +130,7 @@ XCOMM   *** END XM CONFIG SECTION ***
 
 XCOMM   *** BEGIN MESAGL AND OPENGL CONFIG SECTION ***
 
-XCOMM escher, gears, morph3d, pipes, superquadrics, sproingies modes use this.
+XCOMM Modes in modes/glx use this.
 XCOMM If your system has libMesaGL & widgets,
 XCOMM remove the 'XCOMM  ' from the next line.
 XCOMM  #define GLLibrary
@@ -131,14 +145,16 @@ GLINC = -I/usr/local/include
 XCOMM If you get an error "Cannot find libMesaGL" while linking, set GLLIBPATH
 XCOMM to the directory libMesaGL.* is in.  Below is a guess.
 XCOMM !!!WARNING!!! Known security hole with MesaGL < 3.0 if setuid root
-GLLIB = -L/usr/local/lib -lMesaGL -lMesaGLU
+GLLIB = -L/usr/local/lib -lGL -lGLU
+XCOMM   GLLIB = -L/usr/local/lib -lMesaGL -lMesaGLU
 
-XCOMM On SGI
-XCOMM  GLLIB = -lGL -lGLU -lgl
-XCOMM On other OpenGL
-XCOMM  GLLIB = -lGL -lGLU
-XCOMM On Sun with OGL1.1
-XCOMM  GLDEF += -DSUN_OGL_NO_VERTEX_MACROS
+#if SGIArchitecture
+GLLIB = -lGL -lGLU -lgl
+#endif
+#if SunArchitecture
+XCOMM with OGL1.1
+GLDEF += -DSUN_OGL_NO_VERTEX_MACROS
+#endif
 XCOMM 3Dfx card
 XCOMM  GLDEF += -DFX
 XCOMM Threads
@@ -255,9 +271,11 @@ XCOMM This is the default directory to look in for modules. It can be
 XCOMM a colon separated list of directories.
 DEF_MODULEPATH = $(USRLIBDIR)/X11/xlock_modules
 
+#ifdef LinuxArchitecture
 XCOMM Flag to compile the main program so that global variables will be
-XCOMM available to modules
+XCOMM available to modules (gives errors on Sun).
 MODULEFLAGS = -rdynamic
+#endif
 
 MODULEDEF = -DDEF_MODULEPATH=\"$(DEF_MODULEPATH)\" -DUSE_MODULES
 
@@ -522,10 +540,13 @@ $(SOUNDDEF) $(PASSWDINC) $(XPMINC) $(GLINC) $(DTSAVERINC) $(DPMSINC) \
 $(SOUNDINC) $(XLOCKINC)
 
 DEPLIBS = $(DEPXLIB)
-LOCAL_LIBRARIES = $(MODULELIB) $(XLIB) \
-$(XPMLIB) $(GLLIB) $(DTSAVERLIB) $(DPMSLIB) $(SOUNDLIB)
-MLIBS = $(XPMLIB) $(XMLIB) $(EDITRESLIB) -lXt $(XLIB) $(SMLIB) $(ICELIB)
-ALIBS = $(XAWLIB) -lXt $(XLIB) $(SMLIB) $(ICELIB)
+#if SGIArchitecture
+FIRSTLIB = -L/usr/lib32
+#endif
+LOCAL_LIBRARIES = $(FIRSTLIB) $(MODULELIB) $(XLIB) \
+$(XPMLIB) $(GLLIB) $(TTFLIB) $(GLTTLIB) $(DTSAVERLIB) $(DPMSLIB) $(SOUNDLIB)
+MLIBS = $(FIRSTLIB) $(XPMLIB) $(XMLIB) $(EDITRESLIB) -lXt \
+$(XLIB) $(SMLIB) $(ICELIB)
 LINTLIBS = $(LINTXLIB)
 #if HasLibCrypt
        CRYPTLIB = -lcrypt
