@@ -62,7 +62,7 @@ static const char sccsid[] = "@(#)bomb.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_bomb
 
 ModeSpecOpt bomb_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   bomb_description =
