@@ -93,7 +93,7 @@ static const char sccsid[] = "@(#)bouboule.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_bouboule
 
 ModeSpecOpt bouboule_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   bouboule_description =
