@@ -100,7 +100,7 @@ static const char sccsid[] = "@(#)bounce.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_bounce
 
 ModeSpecOpt bounce_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   bounce_description =
