@@ -64,7 +64,7 @@ struct glb_config glb_config =
 #ifdef MODE_bubble3d
 
 ModeSpecOpt bubble3d_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   bubble3d_description =
@@ -181,7 +181,7 @@ release_bubble3d(ModeInfo * mi)
 			}
 		}
 		(void) free((void *) contexts);
-		contexts = NULL;
+		contexts = (struct context *) NULL;
 	}
 	FreeAllGL(mi);
 }
