@@ -101,7 +101,7 @@ static const char sccsid[] = "@(#)cage.c	5.01 2001/03/01 xlockmore";
 #include "e_textures.h"
 
 ModeSpecOpt cage_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   cage_description =
@@ -153,7 +153,7 @@ static float lmodel_twoside[] =
 static float MaterialWhite[] =
 {0.7, 0.7, 0.7, 1.0};
 
-static cagestruct *cage = NULL;
+static cagestruct *cage = (cagestruct *) NULL;
 static GLuint objects = 0;
 
 #define PlankWidth      3.0
@@ -386,11 +386,11 @@ release_cage(ModeInfo * mi)
 					glDeleteLists(objects, MaxObj);
 					objects = 0;
 				}
-				cp->glx_context = NULL;
+				cp->glx_context = (GLXContext *) NULL;
 			}
 		}
 		(void) free((void *) cage);
-		cage = NULL;
+		cage = (cagestruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
