@@ -308,7 +308,7 @@ typedef struct {
 } firestruct;
 
 /* array of firestruct indexed by screen number */
-static firestruct *fire = NULL;
+static firestruct *fire = (firestruct *) NULL;
 
 /*
  *-----------------------------------------------------------------------------
@@ -888,17 +888,18 @@ free_fire(firestruct *fs)
 			mode_font->min_char_or_byte2 + 1);
 		fs->fontbase = None;
 	}
+
 	if (fs->p != NULL) {
 		(void) free((void *) fs->p);
-		fs->p = NULL;
+		fs->p = (part *) NULL;
 	}
 	if (fs->r != NULL) {
 		(void) free((void *) fs->r);
-		fs->r = NULL;
+		fs->r = (rain *) NULL;
 	}
 	if (fs->treepos != NULL) {
 		(void) free((void *) fs->treepos);
-		fs->treepos = NULL;
+		fs->treepos = (treestruct *) NULL;
 	}
 	if (fs->ttexture != None) {
 		glDeleteTextures(1, &fs->treeid);
@@ -1011,7 +1012,7 @@ void release_fire(ModeInfo * mi)
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 		free_fire(&fire[screen]);
 	(void) free((void *) fire);
-	fire = NULL;
+	fire = (firestruct *) NULL;
     }
     if (mode_font != None)
     {
