@@ -227,9 +227,9 @@ typedef struct {
 } planetstruct;
 
 
-static planetstruct *planets = NULL;
-
+static planetstruct *planets = (planetstruct *) NULL;
 
+#if 0
 static inline void
 normalize(GLfloat v[3])
 {
@@ -243,7 +243,7 @@ normalize(GLfloat v[3])
 		v[0] = v[1] = v[2] = 0;
 	}
 }
-
+#endif
 
 /* Set up and enable texturing on our object */
 static void
@@ -287,7 +287,7 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
   glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 
   if (data != NULL) {
-	free(data);
+	(void) free((void *) data);
   }
 }
 
@@ -675,8 +675,8 @@ init_glplanet(ModeInfo * mi)
 		exit(1);
       }
 
-	free (f);
-	free (b);
+	(void) free((void *) f);
+	(void) free((void *) b);
   } 
 
 
@@ -766,7 +766,7 @@ release_glplanet(ModeInfo * mi)
 	  }
 	}
 	(void) free((void *) planets);
-	planets = NULL;
+	planets = (planetstruct *) NULL;
   }
   FreeAllGL(mi);
 }
