@@ -208,7 +208,7 @@ static float MaterialGray6[] =
 static float MaterialGray8[] =
 {0.8, 0.8, 0.8, 1.0};
 
-static moebiusstruct *moebius = NULL;
+static moebiusstruct *moebius = (moebiusstruct *) NULL;
 static GLuint objects = 0;
 
 #define NUM_SCENES      2
@@ -849,7 +849,7 @@ release_moebius(ModeInfo * mi)
 {
 	if (moebius != NULL) {
 		(void) free((void *) moebius);
-		moebius = NULL;
+		moebius = (moebiusstruct *) NULL;
 	}
 	if (glIsList(objects)) {
 		glDeleteLists(objects, MaxObj);
