@@ -80,7 +80,7 @@ static const char sccsid[] = "@(#)morph3d.c	5.01 2001/03/01 xlockmore";
 #ifdef MODE_moebius
 
 ModeSpecOpt morph3d_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   morph3d_description =
@@ -173,11 +173,11 @@ static float MaterialWhite[] =
 static float MaterialGray[] =
 {0.5, 0.5, 0.5, 1.0};
 
-static morph3dstruct *morph3d = NULL;
+static morph3dstruct *morph3d = (morph3dstruct *) NULL;
 
 #define TRIANGLE(Edge, Amp, Divisions, Z, VS)                                                                    \
 {                                                                                                                \
-  GLfloat   Xf,Yf,Xa,Yb,Xf2,Yf2,Yf_2,Yb2,Yb_2;                                                                   \
+  GLfloat   Xf,Yf,Xa,Yb=0.0,Xf2=0.0,Yf2=0.0,Yf_2=0.0,Yb2,Yb_2;                                                   \
   GLfloat   Factor=0.0,Factor1,Factor2;                                                                          \
   GLfloat   VertX,VertY,VertZ,NeiAX,NeiAY,NeiAZ,NeiBX,NeiBY,NeiBZ;                                               \
   GLfloat   Ax,Ay;                                                                                               \
@@ -911,7 +911,7 @@ release_morph3d(ModeInfo * mi)
 {
 	if (morph3d != NULL) {
 		(void) free((void *) morph3d);
-		morph3d = NULL;
+		morph3d = (morph3dstruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
