@@ -214,7 +214,7 @@ static float MaterialWhite[] =
 static float MaterialGray[] =
 {0.2, 0.2, 0.2, 1.0};
 
-static pipesstruct *pipes = NULL;
+static pipesstruct *pipes = (pipesstruct *) NULL;
 
 
 static void
@@ -679,7 +679,7 @@ release_pipes(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_factory(MI_DISPLAY(mi), &pipes[screen]);
 		(void) free((void *) pipes);
-		pipes = NULL;
+		pipes = (pipesstruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
