@@ -79,7 +79,7 @@ static const char sccsid[] = "@(#)stairs.c	5.01 2001/03/01 xlockmore";
 #include "e_textures.h"
 
 ModeSpecOpt stairs_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   stairs_description =
@@ -201,7 +201,7 @@ static float positions[] =
 
 #define NPOSITIONS ((sizeof positions) / (sizeof positions[0]))
 
-static stairsstruct *stairs = NULL;
+static stairsstruct *stairs = (stairsstruct *) NULL;
 #if 0
 static GLuint objects = 0;
 #endif
@@ -409,7 +409,7 @@ release_stairs(ModeInfo * mi)
 		}
 #endif
 		(void) free((void *) stairs);
-		stairs = NULL;
+		stairs = (stairsstruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
