@@ -163,7 +163,7 @@ typedef struct {
 	state       now, later;
 } superquadricsstruct;
 
-static superquadricsstruct *superquadrics = NULL;
+static superquadricsstruct *superquadrics = (superquadricsstruct *) NULL;
 
 #define CLIP_NORMALS 10000.0
 
@@ -777,7 +777,7 @@ release_superquadrics(ModeInfo * mi)
 {
 	if (superquadrics != NULL) {
 		(void) free((void *) superquadrics);
-		superquadrics = NULL;
+		superquadrics = (superquadricsstruct *) NULL;
 	}
 	FreeAllGL(mi);
 }
