@@ -49,7 +49,7 @@ static const char sccsid[] = "@(#)ifs.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_ifs
 
 ModeSpecOpt ifs_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   ifs_description =
