@@ -2923,7 +2923,7 @@ init_life(ModeInfo * mi)
 		lp->ncols = nccols / 2;
 		lp->nrows = 2 * (ncrows / 4);
 		lp->xb = (lp->width - lp->xs * nccols) / 2 + lp->xs / 2;
-		lp->yb = (lp->height - lp->ys * (ncrows / 2) * 2) / 2 + lp->ys;
+		lp->yb = (lp->height - lp->ys * (ncrows / 2) * 2) / 2 + lp->ys - 2;
 		for (sides = 0; sides < 6; sides++) {
 			lp->shape.hexagon[sides].x = (lp->xs - 1) * hexagonUnit[sides].x;
 			lp->shape.hexagon[sides].y =
