@@ -85,7 +85,8 @@ static const char sccsid[] = "@(#)matrix.c	5.00 2000/11/01 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
-ModeSpecOpt matrix_opts = {0, NULL, 0, NULL, NULL};
+ModeSpecOpt matrix_opts =
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   matrix_description =
