@@ -60,7 +60,7 @@ static const char sccsid[] = "@(#)petal.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_petal
 
 ModeSpecOpt petal_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   petal_description =
