@@ -51,7 +51,7 @@ static const char sccsid[] = "@(#)rotor.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_rotor
 
 ModeSpecOpt rotor_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   rotor_description =
