@@ -51,7 +51,8 @@ static const char sccsid[] = "@(#)scooter.c	5.01 2001/03/02 xlockmore";
 
 #ifdef MODE_scooter
 
-ModeSpecOpt scooter_opts = {0, NULL, 0, NULL, NULL};
+ModeSpecOpt scooter_opts =
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct scooter_description =
@@ -112,7 +113,7 @@ static struct Star *stars = NULL;
 static struct Door *doors = NULL;
 static struct ZElement *zelements = NULL;
 static int doorcount, ztotal, speed, zelements_per_door, zelement_distance, spectator_zelement,
-	projnorm_z, rotationDuration, rotationStep, starcount, z_maxdepth;
+	projnorm_z, rotationDuration, rotationStep, starcount;
 
 static struct Angle3D currentRotation, rotationDelta;
 
@@ -190,7 +191,7 @@ int i;
 	zelements_per_door = 60;
 	zelement_distance = 300;
 	ztotal = doorcount * zelements_per_door;
-	z_maxdepth = ztotal * zelement_distance;
+	/* z_maxdepth = ztotal * zelement_distance; */
 	if( starcount > ztotal ) starcount = ztotal;
 
 	halt_scooter = 0;
@@ -249,10 +250,7 @@ static void cleardoors( struct ModeInfo_s *mi )
 
 static inline float projection( int zval )
 {
-	if ( zval > 0 )
-		return (projnorm_z / (PROJECTION_DEGREE * zval));
-	else
-		return (projnorm_z * pow(1.22,-(zval/200*PROJECTION_DEGREE)));
+	return (projnorm_z / (PROJECTION_DEGREE * zval));
 /* this is another formula. it is not limited to z>0 but it pulls too strong towards the screen center */
 /*      return (projnorm_z * pow(1.22,-(zval/200*PROJ_CURVEDNESS)))*/
 }
@@ -302,20 +300,20 @@ float	cosa = COS(angle->x),
 	/* X axis */
 	tmp.z = src->z;
 	tmp.y = src->y;
-	dest->z = tmp.z * cosa - tmp.y * sina;
-	dest->y = tmp.z * sina + tmp.y * cosa;
+	dest->z = (int) (tmp.z * cosa - tmp.y * sina);
+	dest->y = (int) (tmp.z * sina + tmp.y * cosa);
 
 	/* Y axis */
 	tmp.z = dest->z;
 	tmp.x = src->x;
-	dest->z = tmp.z * cosb - tmp.x * sinb;
-	dest->x = tmp.z * sinb + tmp.x * cosb;
+	dest->z = (int) (tmp.z * cosb - tmp.x * sinb);
+	dest->x = (int) (tmp.z * sinb + tmp.x * cosb);
 
 	/* Z axis */
 	tmp.x = dest->x;
 	tmp.y = dest->y;
-	dest->x = tmp.x * cosc - tmp.y * sinc;
-	dest->y = tmp.x * sinc + tmp.y * cosc;
+	dest->x = (int) (tmp.x * cosc - tmp.y * sinc);
+	dest->y = (int) (tmp.x * sinc + tmp.y * cosc);
 }
 
 static void randomcolor( struct ColorRGB *col )
@@ -423,9 +421,9 @@ float rot = SIN((SINUSTABLE_SIZE/2)*rotationStep/rotationDuration);
 		rotationStep = 0;
 	}
 
-	currentRotation.x += rot * rotationDelta.x;
-	currentRotation.y += rot * rotationDelta.y;
-	currentRotation.z += rot * rotationDelta.z;
+	currentRotation.x += (int) (rot * rotationDelta.x);
+	currentRotation.y += (int) (rot * rotationDelta.y);
+	currentRotation.z += (int) (rot * rotationDelta.z);
 
 	currentRotation.x &= SINUSTABLE_MASK;
 	currentRotation.y &= SINUSTABLE_MASK;
@@ -593,11 +591,11 @@ float m;
 	m = ( new2.x == new1.x ) ? 0 : ((float)(new2.y - new1.y) / (new2.x - new1.x));
 
 	if( new1.y < rect->lefttop.y ) {
-		if( m ) new1.x += (rect->lefttop.y - new1.y)/m;
+		if( m ) new1.x += (int) ((rect->lefttop.y - new1.y)/m);
 		new1.y = rect->lefttop.y;
 	}
 	if( new2.y > rect->rightbottom.y ) {
-		if( m ) new2.x -= (new2.y - rect->rightbottom.y)/m;
+		if( m ) new2.x -= (int) ((new2.y - rect->rightbottom.y)/m);
 		new2.y = rect->rightbottom.y;
 	}
 
@@ -616,11 +614,11 @@ float m;
 	m = ( new2.x == new1.x ) ? 0 : ((float)(new2.y - new1.y) / (new2.x - new1.x));
 
 	if( new1.x < rect->lefttop.x ) {
-		new1.y += (rect->lefttop.y - new1.y)*m;
+		new1.y += (int) ((rect->lefttop.y - new1.y)*m);
 		new1.x = rect->lefttop.x;
 	}
 	if( new2.y > rect->rightbottom.y ) {
-		new2.y -= (new2.y - rect->rightbottom.y)*m;
+		new2.y -= (int) ((new2.y - rect->rightbottom.y)*m);
 		new2.x = rect->rightbottom.x;
 	}
 
@@ -668,11 +666,13 @@ struct Rect rect = { {0,0}, {0,0} };
 		door_3d(&doors[i]);
 
 		for( j=0; j<4; j++ ) {
-			if( doors[i].coords[j].z < 0 ) break;
+			if( doors[i].coords[j].z <= 0 ) break;
 
 			proj = projection(doors[i].coords[j].z) * aspect_scale;
-			lines[j].x = midx + (doors[i].coords[j].x * proj / SPACE_XY_FACTOR);
-			lines[j].y = midy - (doors[i].coords[j].y * proj / SPACE_XY_FACTOR);
+			lines[j].x = midx + (int) (doors[i].coords[j].x *
+				proj / SPACE_XY_FACTOR);
+			lines[j].y = midy - (int) (doors[i].coords[j].y *
+				proj / SPACE_XY_FACTOR);
 		}
 		if( j<4 ) continue;
 
@@ -721,22 +721,22 @@ int i;
 		coords.y += ze->pos.y;
 		coords.z += ze->pos.z;
 
-		if( coords.z < 0 ) continue;
+		if( coords.z <= 0 ) continue;
 
 
 		/* projection and clipping (trivial for a rectangle) */
 
 		proj = projection(coords.z) * aspect_scale;
 
-		lefttop.x = midx + ((coords.x - stars[i].width/2)  * proj / SPACE_XY_FACTOR);
-		lefttop.y = midy - ((coords.y + stars[i].height/2) * proj / SPACE_XY_FACTOR);
+		lefttop.x = midx + (int) ((coords.x - stars[i].width/2)  * proj / SPACE_XY_FACTOR);
+		lefttop.y = midy - (int) ((coords.y + stars[i].height/2) * proj / SPACE_XY_FACTOR);
 		if( lefttop.x < 0 ) lefttop.x = 0;
 		else if( lefttop.x >= width ) continue;
 		if( lefttop.y < 0 ) lefttop.y = 0;
 		else if( lefttop.y >= height ) continue;
 
-		rightbottom.x = midx + ((coords.x + stars[i].width/2)  * proj / SPACE_XY_FACTOR);
-		rightbottom.y = midy - ((coords.y - stars[i].height/2) * proj / SPACE_XY_FACTOR);
+		rightbottom.x = midx + (int) ((coords.x + stars[i].width/2)  * proj / SPACE_XY_FACTOR);
+		rightbottom.y = midy - (int) ((coords.y - stars[i].height/2) * proj / SPACE_XY_FACTOR);
 		if( rightbottom.x < 0 ) continue;
 		else if( rightbottom.x >= width ) rightbottom.x = width - 1;
 		if( rightbottom.y < 0 ) continue;
