@@ -43,7 +43,7 @@ static const char sccsid[] = "@(#)slip.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_slip
 
 ModeSpecOpt slip_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   slip_description =
