@@ -85,30 +85,26 @@ enum Suits {spade, diamond, club, heart};
 #ifdef FR
 // Ace => As, Jack => Valet,
 // Queen = Reine (Dame), King = Roi, Joker = Joker
-static char *RankNames[] = {NULL, (char *) "A",
-	(char *) "2", (char *) "3", (char *) "4", (char *) "5", (char *) "6",
-	(char *) "7", (char *) "8", (char *) "9", (char *) "10",
-	(char *) "V", (char *) "D", (char *) "R"};
+static const char *RankNames[] = {"", "A",
+	"2", "3", "4", "5", "6", "7", "8", "9", "10",
+	"V", "D", "R"};
 #else
 #ifdef NL
 // Ace => Aas, Jack => Boer (Farmer),
 // Queen = Vrouw (Lady), King = Heer (Gentleman), Joker = Joker
-static char *RankNames[] = {NULL, (char *) "A",
-	(char *) "2", (char *) "3", (char *) "4", (char *) "5", (char *) "6",
-	(char *) "7", (char *) "8", (char *) "9", (char *) "10",
-	(char *) "B", (char *) "V", (char *) "H"};
+static const char *RankNames[] = {"", "A",
+	"2", "3", "4", "5", "6", "7", "8", "9", "10",
+	"B", "V", "H"};
 #else
 #ifdef RU
 // Some may be approximations to Cyrillic
-static char *RankNames[] = {NULL, (char *) "T",
-	(char *) "2", (char *) "3", (char *) "4", (char *) "5", (char *) "6",
-	(char *) "7", (char *) "8", (char *) "9", (char *) "10",
-	(char *) "B", (char *) "Q", (char *) "K"};
+static const char *RankNames[] = {"", "T",
+	"2", "3", "4", "5", "6", "7", "8", "9", "10",
+	"B", "Q", "K"};
 #else
-static char *RankNames[] = {NULL, (char *) "A",
-	(char *) "2", (char *) "3", (char *) "4", (char *) "5", (char *) "6",
-	(char *) "7", (char *) "8", (char *) "9", (char *) "10",
-	(char *) "J", (char *) "Q", (char *) "K"};
+static const char *RankNames[] = {"", "A",
+	"2", "3", "4", "5", "6", "7", "8", "9", "10",
+	"J", "Q", "K"};
 #endif
 #endif
 #endif
@@ -1257,7 +1253,7 @@ ModeSpecOpt solitare_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 #else
 ModeSpecOpt solitare_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 #endif
 
 #ifdef USE_MODULES
