@@ -49,7 +49,7 @@ static const char sccsid[] = "@(#)space.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_space
 
 ModeSpecOpt space_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   space_description =
