@@ -54,7 +54,7 @@ static const char sccsid[] = "@(#)swirl.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_swirl
 
 ModeSpecOpt swirl_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   swirl_description =
