@@ -69,7 +69,7 @@ static const char sccsid[] = "@(#)triangle.c	5.00 2000/11/01 xlockmore";
 #ifdef MODE_triangle
 
 ModeSpecOpt triangle_opts =
-{0, NULL, 0, NULL, NULL};
+{0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
 ModStruct   triangle_description =
