@@ -669,7 +669,7 @@ init_voters(ModeInfo * mi)
 		vp->ncols = nccols / 2;
 		vp->nrows = 2 * (ncrows / 4);
 		vp->xb = (vp->width - vp->xs * nccols) / 2 + vp->xs / 2;
-		vp->yb = (vp->height - vp->ys * (ncrows / 2) * 2) / 2 + vp->ys;
+		vp->yb = (vp->height - vp->ys * (ncrows / 2) * 2) / 2 + vp->ys - 2;
 		for (sides = 0; sides < 6; sides++) {
 			vp->hexagonList[sides].x = (vp->xs - 1) * hexagonUnit[sides].x;
 			vp->hexagonList[sides].y =
