@@ -220,7 +220,7 @@ sel_image(struct dirent *name)
 			filename_tmp = filename_tmp + ip;
 		}
 		if ( strlen( filename_tmp ) != 0 ) {
-			if (frags[numfrag] != NULL)
+			if (numfrag > 0 && frags[numfrag] != NULL)
 				(void) free((void *) frags[numfrag]);
 			if ((frags[numfrag] = (char *) malloc(strlen(filename_tmp) +
 					1)) == NULL) {
